gofKendallKS is a wrapper for the function BiCopGofTest from the package gofKendallKS(copula, x, param = 0, param.est = T, margins = "ranks",
M = 100, execute.times.comp = T)"gaussian", "clayton", "gumbel" and "frank".TRUE or FALSE. TRUE means that param will be estimated with a maximum likelihood estimation."ranks", which is the standard approach to convert data in such a case. Alternatively can the following distributions be spM is at least 100.class gofCOP with the componentsdata = cbind(rnorm(100), rnorm(100))
gofKendallKS("gaussian", data, M = 1)Run the code above in your browser using DataLab