gofRosenblattSnB is a wrapper for the functions gofCopula, fitCopula, ellipCopula and archmCopula from the package gofRosenblattSnB contains the SnB gof test for copulae from Genest (2009) and compares the empirical copula against a parametric estimate of the copula derived under the null hypothesis. The approximate p-values are obtained via parametric bootstrapping. It is possible to insert datasets of all dimensions above 1 and the possible copulae are "gaussian", "t", "gumbel", "clayton" and "frank". The parameter estimation is performed with pseudo maximum likelihood method. In case the estimation fails, inversion of Kendall's tau is used.gofRosenblattSnB(copula, x, M = 1000, param = 0.5, param.est = T, df = 4,
df.est = T, margins = "ranks", execute.times.comp = T)"gaussian", "t", "clayton", "gumbel" and "frank".TRUE or FALSE. TRUE means that param will be estimated."t"-copula.df shall be estimated. Has to be either FALSE or TRUE, where TRUE means that it will be estimated."ranks", which is the standard approach to convert data in such a case. Alternatively can the following distributions be spM is at least 100.class gofCOP with the componentsdata = cbind(rnorm(100), rnorm(100), rnorm(100))
gofRosenblattSnB("gaussian", data, M = 20)Run the code above in your browser using DataLab