gofADGamma is a wrapper for the functions gofCopula, fitCopula, ellipCopula and archmCopula from the package gofADGamma contains the ADGamma gof tests for copulae, described in Genest (2009) and Hofert (2014), and compares the empirical copula against a parametric estimate of the copula derived under the null hypothesis. The approximate p-values are computed with a parametric bootstrap. It is possible to insert datasets of all dimensions above 1 and the possible copulae are "gaussian", "t", "gumbel", "clayton" and "frank". The parameter estimation is performed with pseudo maximum likelihood method. In case the estimation fails, inversion of Kendall's tau is used.gofADGamma(copula, x, M = 1000, param = 0.5, param.est = T, df = 4, df.est = T,
margins = "ranks", execute.times.comp = T)"gaussian", "t", "clayton" and "gumbel".TRUE or FALSE. TRUE means that param will be estimated."t"-copula.df shall be estimated. Has to be either FALSE or TRUE, where TRUE means that it will be estimated."ranks", which is the standard approach to convert data in such a case. Alternatively can the following distributions be spM is at least 100.class gofCOP with the componentsADGofTest::ad.test), where $x_i = \sum_{j=1}^d (- \ln u_{ij})$, $\Gamma_d()$ denotes the distribution function of the gamma distribution with shape parameter d and shape parameter one (being equal to an Erlang(d) distribution function).
The test statistic is then given by
$$T = -n - \sum_{i=1}^n \frac{2i - 1}{n} [\ln(G(x_i)) + \ln(1 - G(x_{n+1-i}))].$$
The approximate p-value is computed by the formula, see data = cbind(rnorm(100), rnorm(100), rnorm(100))
gofADGamma("gaussian", data, M = 20)Run the code above in your browser using DataLab