gofHybrid combines all tests in this package to perform the hybrid test presented in Zhang et al. (2015). The test gives the possibility to combine several single tests which is helpful since in different test scenarios are different tests the most powerful.gofHybrid(copula, x, testset = c("gofPIOSRn", "gofKernel"), margins = "ranks",
M = 1000, execute.times.comp = T, param = 0.5, param.est = T, df = 4,
df.est = T, m = 1, MJ = 100, delta.J = 0.5, nodes.Integration = 12,
m_b = 0.5, zeta.m = 0, b_Rn = 0.05)"gofPIOSRn", "gofPIOSTn", "gofKernel", "gofRosenblattSnB", "gofRosenblattSnC", "gofADChisq", "gofADGamma", "gofSn", "ranks", which is the standard approach to convert data in such a case. Alternatively can the following distributions be spM is at least 100.TRUE or FALSE. TRUE means that param will be estimated."t"-copula.df shall be estimated. Has to be either FALSE or TRUE, where TRUE means that it will be estimated.gofPIOSTn is part of testset.gofKernel is part of testset.gofKernel is part of testset.gofKernel is part of testset.gofRn is part of testset.gofRn is part of testset.gofRn is part of testset.class gofCOP with the componentsdata = cbind(rnorm(100), rnorm(100))
gofHybrid("gaussian", data, testset = c("gofRosenblattSnB", "gofRosenblattSnC"), M = 10)Run the code above in your browser using DataLab