gofHybrid combines all tests in this package to perform the hybrid test presented in Zhang et al. (2015). The test gives the possibility to combine several single tests which is helpful since in different test scenarios are different tests the most powerful.
gofHybrid(copula, x, testset = c("gofPIOSRn", "gofKernel"), margins = "ranks", dispstr = "ex", M = 1000, execute.times.comp = T, param = 0.5, param.est = T, df = 4, df.est = T, m = 1, MJ = 100, delta.J = 0.5, nodes.Integration = 12, m_b = 0.5, zeta.m = 0, b_Rn = 0.05, processes = 1)"gofPIOSRn", "gofPIOSTn", "gofKernel", "gofRosenblattSnB", "gofRosenblattSnC", "gofRosenblattChisq", "gofRosenblattGamma", "gofSn", "gofKendallCvM", "gofKendallKS", "gofWhite", "gofRn".
"ranks", which is the standard approach to convert data in such a case. Alternatively can the following distributions be specified: "beta", "cauchy", Chi-squared ("chisq"), "f", "gamma", Log normal ("lnorm"), Normal ("norm"), "t", "weibull", Exponential ("exp").
copula.
M is at least 100.
TRUE or FALSE. TRUE means that param will be estimated.
"t"-copula.
df shall be estimated. Has to be either FALSE or TRUE, where TRUE means that it will be estimated.
gofPIOSTn is part of testset.
gofKernel is part of testset.
gofKernel is part of testset.
gofKernel is part of testset.
gofRn is part of testset.
gofRn is part of testset.
gofRn is part of testset.
class gofCOP with the components
gofCOP with the componentsThe p-value is a combination of the single tests in the following way: $$p_n^{hybrid} = \min(q \cdot \min{(p_n^{(1)}, \dots, p_n^{(q)})}, 1)$$ where $q$ is the number of tests and $pn^(i)$ the p-value of the test $i$. It is ensured that the hybrid test is consistent as long as at least one of the tests is consistent.
The computation of the individual p-values is performed as described in the details of this tests. Note that the derivation differs.
For small values of M, initializing the parallization via processes does not make sense. The registration of the parallel processes increases the computation time. Please consider to enable parallelization just for high values of M.
data(IndexReturns)
gofHybrid("normal", IndexReturns[c(1:100),c(1:2)],
testset = c("gofRosenblattSnB", "gofRosenblattSnC"), M = 10)
Run the code above in your browser using DataLab