gofRn is a wrapper for the functions gofCopula, fitCopula, ellipCopula and archmCopula from the package gofRn performs the gof test from Genest et al. (2013) for copulae and compares the empirical copula against a parametric estimate of the copula derived under the null hypothesis. The approximate p-values are computed with a fast multiplier approach. It is just possible to insert datasets of dimension 2 and the possible copulae are "gaussian", "t", "gumbel", "clayton" and "frank". The parameter estimation is performed with pseudo maximum likelihood method. In case the estimation fails, inversion of Kendall's tau is used.gofRn(copula, x, M = 1000, param = 0.5, param.est = T, df = 4, df.est = T,
m_b = 0.5, zeta.m = 0, b_Rn = 0.05, execute.times.comp = T)"gaussian", "t", "clayton", "gumbel" and "frank".TRUE or FALSE. TRUE means that param will be estimated."t"-copula.df shall be estimated. Has to be either FALSE or TRUE, where TRUE means that it will be estimated.M is at least 100.class gofCOP with the componentsdata = cbind(rnorm(100), rnorm(100))
gofRn("gaussian", data, M = 20)Run the code above in your browser using DataLab