gofWhite is a wrapper for the function BiCopGofTest from the package gofWhite(copula, x, M = 1000, param = 0, param.est = T, df = 0, df.est = T,
margins = "ranks", execute.times.comp = T)"gaussian", "t", "clayton", "gumbel" and "frank".TRUE or FALSE. TRUE means that param will be estimated with a maximum likelihood estimation."t"-copula.df shall be estimated. Has to be either FALSE or TRUE, where TRUE means that it will be estimated."ranks", which is the standard approach to convert data in such a case. Alternatively can the following distributions be spM is at least 100.class gofCOP with the componentsdata = cbind(rnorm(100), rnorm(100))
gofWhite("gaussian", data)Run the code above in your browser using DataLab